Add missing staging settings

In the local environment Monorail is now ran with the staging
configuration. This fixes it.

GitOrigin-RevId: f2cdf35c33a8b956a038287fc972b97e918d1bf9
diff --git a/settings.py b/settings.py
index 1d08454..79d94f5 100644
--- a/settings.py
+++ b/settings.py
@@ -174,17 +174,15 @@
 unit_test_mode = os.environ['SERVER_SOFTWARE'].startswith('test')
 local_mode = not (os.getenv('GAE_ENV') == 'standard' or unit_test_mode)
 
 # If we assume 1KB each, then this would be 400 MB for this cache in frontends
 # that have only 1024 MB total.
-issue_cache_max_size = 400 * 1000
+issue_cache_max_size = 10 * 1000
 
 # If we assume 1KB each, then this would be 400 MB for this cache in frontends
 # that have only 1024 MB total.
-comment_cache_max_size = 400 * 1000
+comment_cache_max_size = 10 * 1000
 
-# 150K users should be enough for all the frequent daily users plus the
-# occasional users that are mentioned on any popular pages.
-user_cache_max_size = 150 * 1000
+user_cache_max_size = 10 * 1000
 
 # Normally we use the default namespace, but during development it is
 # sometimes useful to run a tainted version on staging that has a separate
@@ -268,6 +266,7 @@
 # should have the specified host, otherwise it will be redirected such that
 # the specified host is used.
 branded_domains = {}  # defaults to empty for localhost
+branded_domains_staging = {} # now staging is used for the local server
 branded_domains_prod = {
     '*': 'bugs.avm99963.com',
 }
@@ -275,6 +274,7 @@
 # The site home page will immediately redirect to a default project for these
 # domains, if the project can be viewed.  Structure is {hostport: project_name}.
 domain_to_default_project = {}  # defaults to empty for localhost
+domain_to_default_project_staging = {} # now staging is used for the local server
 domain_to_default_project_prod = {}
@@ -174,17 +174,15 @@
 local_mode = not (os.getenv('GAE_ENV') == 'standard' or unit_test_mode)
 
-# If we assume 1KB each, then this would be 400 MB for this cache in frontends
+# If we assume 1KB each, then this would be 10 MB for this cache in frontends
 # that have only 1024 MB total.
@@ -174,17 +174,15 @@
 
-# If we assume 1KB each, then this would be 400 MB for this cache in frontends
+# If we assume 1KB each, then this would be 10 MB for this cache in frontends
 # that have only 1024 MB total.